
### Before running this example, download the "foreign" package to upload the dataset
### You will also have to download and run the PROCESS macro by Hayes, see :https://haskayne.ucalgary.ca/CCRAM/resource-hub

library(foreign)
d<-read.dta("https://stats.idre.ucla.edu/stat/stata/examples/methods_matter/chapter12/catholic.dta")
head(d)
d$highinc=d$faminc8

d$highinc <- as.numeric(d$highinc)

#dichotomise faminc8 --> Families with higher income vs. others
d$highinc <- cut(d$highinc,
                 breaks=c(-Inf, 9,  Inf),
                 labels=c(1,0))
#cut creates a factor var, but to have a num one I need to do the following:
d$highinc = ifelse( d$highinc=="1" , 0 , 1 )
table(d$faminc8, d$highinc)


table(d$faminc8, d$highinc)
summary(d)

### Estimates using OLS regression
summary(lm(read8~highinc, data=d))
summary(lm(math12~highinc+read8, data=d))
summary(lm(math12~highinc, data=d))


### Estimates using the PROCESS macro and assumptions of normality for the indirect effect
process (data=d,y="math12",x="highinc",m="read8",total=1,normal=1,
         model=4,seed=90460)

### Estimates using the PROCESS macro and 10k Bootrstrap draws
process (data=d,y="math12",x="highinc",m="read8",total=1,normal=0, boot=10000,
         model=4,seed=90460)


#### Covaroates are created here:
d$male=ifelse(d$female=="yes", 0, 1)
d$eth=ifelse(d$white=="yes", 0, 1)
table(d$mhowfar)
d$mated=ifelse(d$mhowfar=="postsec ed", 0, 1)

### Run the model with covariates
process (data=d,y="math12",x="highinc",m="read8", cov=c("male","mated"), total=1,normal=0, boot=10000,
         model=4,seed=90460)


#### PARALLEL MEDIATION
process (data=d,y="math12",x="highinc",m=c("read8", "math8"),  cov=c("male","mated"), total=1, contrast=1, modelres=1, boot=10000,
         model=4,seed=90460)



#### SERIAL MEDIATION
process (data=d,y="math12",x="highinc",m=c("read8", "math8"),  cov=c("male","mated"), total=1, contrast=1, modelres=1, boot=10000,
         model=6,seed=90460)

#Reverse the serial association
process (data=d,y="math12",x="highinc",m=c("math8", "read8"),  cov=c("male","mated"), total=1, contrast=1, modelres=1, boot=10000,
         model=6,seed=90460)

